@@ -16,21 +16,25 @@ class pamda_timer:
             - Type: function | method
             - What: The name of the process being timed
         """
-        if not __fn__.__dict__.get("__isCurried__"):
-            __fn__ = curry_obj(__fn__)
-        if __fn__.__arity__ != 0:
-            raise Exception("The function being timed must have an arity of 0. Consider thunkifying the function first.")
         self.__fn__ = __fn__
-        update_wrapper(self, __fn__)
 
-    def __call__(self):
+    def __call__(self, *args, **kwargs):
         """
         Function:
 
-        Test the timer by running the function being timed.
+        Test the function processing time.
+
+        Optional:
+
+        - `args`:
+            - Type: any
+            - What: The arguments to pass to the function
+        - `kwargs`:
+            - Type: any
+            - What: The keyword arguments to pass to the function
         """
         start = time.time()
-        out = self.__fn__()
+        out = self.__fn__(*args, **kwargs)
         print(f"{self.__fn__.__qualname__}: {round(time.time() - start,4)}s")
         return out
 
